# -*- coding: UTF-8 -*-

import md5
import base64
import datetime
import urllib2
import ConfigParser
import json

class SSSClient:

    ServerAddr = ''
    SendUrl = ''
    AccountSid = ''
    AccountToken = ''
    AppId = ''
    CurrentDate = ''
    Result = {}

    # 初始化，默认读取配置文件信息
    def __init__(self):
       # 读取配置文件
        cf = ConfigParser.ConfigParser()
        cf.read("../conf/config.ini")
        self.ServerAddr = cf.get('account', 'ApiUrl')
        self.ReportUrl = cf.get("account","ReportUrl")
        self.AccountSid = cf.get('account', 'AccountSid')
        self.AccountToken = cf.get('account', 'AuthToken')
        self.AppId = cf.get('account', 'AppId')

    # 设置语音请求服务器地址
    def setServer(self, ServerAddr,ReportUrl):
        self.ServerAddr = ServerAddr
        self.ReportUrl = ReportUrl

    # 设置账号
    def setAccount(self, AccountSid, AccountToken):
        self.AccountSid = AccountSid
        self.AccountToken = AccountToken

    # 设置应用id
    def setAppId(self, AppId):
        self.AppId = AppId

    # 发送语音
    # @param phones 接收语音手机号码集合，用英文逗号分隔
    # @param datas 内容数据
    # @param templateId 模板id
    def sendVoice(self, phones, templateId, datas):
        try:
            self.accAuth()
            self.judgeParams(phones, datas, templateId)
        except Exception as e:
            return self.Result
        nowdate = datetime.datetime.now()
        self.CurrentDate = nowdate.strftime("%Y%m%d%H%M%S")
        # 生成sig
        signature = self.AccountSid + self.AccountToken + self.CurrentDate
        sig = md5.new(signature).hexdigest()
        # 拼接URL
        self.SendUrl = self.ServerAddr + "voice/submit"
        # 生成auth
        src = self.AccountSid + ":" + self.CurrentDate
        auth = base64.encodestring(src).strip()
        req = urllib2.Request(self.SendUrl)
        self.setHttpHeader(req)
        req.add_header("sig",sig)
        req.add_header("Authorization", auth)
        # 创建包体
        temp = '['
        if datas != None:
            for each in datas:
                temp += '"%s",' % (each)
            # 去除末尾逗号
            params = temp[0:temp.__len__()-1]
            params += ']'
        else:
            params = "null"
        body = '''{"to": "%s", "datas": %s, "templateId": "%s", "appId": "%s"}''' % (phones, params, templateId, self.AppId)
        req.add_data(body)
        try:
            res = urllib2.urlopen(req)
            data = res.read()
            res.close()
            # 将json数据转化为dict
            self.Result = json.loads(data)
            return self.Result
        except Exception:
            self.Result['statusCode']= '000010'
            self.Result['statusMsg']= '【服务器】服务器请求出错，请确认参数是否正确，如无法解决，请联系工作人员'
            self.Result['object']= ''
            return self.Result

    #获取语音短信的状态报告
    def voiceReport(self):
        try:
            self.accAuth()
        except Exception as e:
            return self.Result
        nowdate = datetime.datetime.now()
        self.CurrentDate = nowdate.strftime("%Y%m%d%H%M%S")
        # 生成sig
        signature = self.AccountSid + self.AccountToken + self.CurrentDate
        sig = md5.new(signature).hexdigest()
        # 拼接URL
        self.SendUrl = self.ReportUrl + "voice/report"
        # 生成auth
        src = self.AccountSid + ":" + self.CurrentDate
        auth = base64.encodestring(src).strip()
        req = urllib2.Request(self.SendUrl)
        self.setHttpHeader(req)
        req.add_header("sig", sig)
        req.add_header("Authorization", auth)
        body = '''{"appId": "%s"}''' % (self.AppId)
        req.add_data(body)
        try:
            res = urllib2.urlopen(req)
            data = res.read()
            res.close()
            # 将json数据转化为dict
            self.Result = json.loads(data)
            return self.Result
        except Exception:
            self.Result['statusCode']= '000010'
            self.Result['statusMsg']= '【服务器】服务器请求出错，请确认参数是否正确，如无法解决，请联系工作人员'
            self.Result['object']= ''
            return self.Result

			
    def judgeParams(self, phones, datas, templateId):
        if (phones=='' or phones== None):
            self.Result['statusCode']= '000006'
            self.Result['statusMsg']= '【短信】接收短信的手机号码为空'
            self.Result['object']= ''
            raise Exception
        if(templateId=='' or templateId==None):
            self.Result['statusCode']= '000008'
            self.Result['statusMsg']= '【短信】短信模板为空或未设置'
            self.Result['object']= ''
            raise Exception



    # 判断真实性
    def accAuth(self):
        if (self.AccountSid == ''):
            self.Result['statusCode']= '000017'
            self.Result['statusMsg']= '【账号】主帐号空'
            self.Result['object']= ''
            raise Exception

        if (self.AccountToken == ''):
            self.Result['statusCode']= '000018'
            self.Result['statusMsg']= '【账号】主帐号令牌空'
            self.Result['object']= ''
            raise Exception

        if (self.AppId == ''):
            self.Result['statusCode']= '000016'
            self.Result['statusMsg']= '【应用】应用ID为空'
            self.Result['object']= ''
            raise Exception

    # 设置请求头
    def setHttpHeader(self, req):
        req.add_header("Accept", "application/json")
        req.add_header("Content-Type", "application/json;charset=utf-8")
